@@ -17,10 +17,6 @@
  * received a copy with calc; if not, write to Free Software Foundation, Inc.
  * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  *
- * @(#) $Revision: 30.3 $
- * @(#) $Id: zrandom.h,v 30.3 2014/08/24 21:56:51 chongo Exp $
- * @(#) $Source: /usr/local/src/bin/calc/RCS/zrandom.h,v $
- *
  * Under source code control:	1997/02/15 04:01:56
  * File existed as early as:	1997
  *
@@ -74,7 +70,7 @@ struct random {
 /*
  * Blum generator function declarations
  */
-E_FUNC RANDOM *zsrandom1(CONST ZVALUE seed, BOOL need_ret);
+E_FUNC RANDOM *zsrandom1(CONST ZVALUE seed, bool need_ret);
 E_FUNC RANDOM *zsrandom2(CONST ZVALUE seed, CONST ZVALUE newn);
 E_FUNC RANDOM *zsrandom4(CONST ZVALUE seed,
 			 CONST ZVALUE ip, CONST ZVALUE iq, long trials);
@@ -86,7 +82,7 @@ E_FUNC void zrandomrange(CONST ZVALUE low, CONST ZVALUE beyond, ZVALUE *res);
 E_FUNC long irandom(long s);
 E_FUNC RANDOM *randomcopy(CONST RANDOM *random);
 E_FUNC void randomfree(RANDOM *random);
-E_FUNC BOOL randomcmp(CONST RANDOM *s1, CONST RANDOM *s2);
+E_FUNC bool randomcmp(CONST RANDOM *s1, CONST RANDOM *s2);
 E_FUNC void randomprint(CONST RANDOM *state, int flags);
 E_FUNC void random_libcalc_cleanup(void);
 
